@@ -389,10 +389,22 @@ def build_joined_dataframe(
     # restructure the joined dataframe to represent system and dataset data categories appropriately
     joined_df = union_data_categories_in_joined_dataframe(joined_df)
 
-    delete_df = joined_df[["system.name", "unioned_data_categories"]][
-        joined_df.groupby(["system.name", "unioned_data_categories"])[
-            "dataset.name"
-        ].transform("count")
+    delete_df = joined_df[
+        [
+            "system.name",
+            "system.privacy_declaration.data_use.name",
+            "system.privacy_declaration.data_subjects.name",
+            "unioned_data_categories",
+        ]
+    ][
+        joined_df.groupby(
+            [
+                "system.name",
+                "system.privacy_declaration.data_use.name",
+                "system.privacy_declaration.data_subjects.name",
+                "unioned_data_categories",
+            ]
+        )["dataset.name"].transform("count")
         > 1
     ].drop_duplicates()
 
@@ -438,6 +450,7 @@ def export_datamap(
             get_server_resource(url, "organization", organization_fides_key, headers)
         ]
     }
+    # Verify this isn't dropping records on the joins
     for resource_type in ["system", "dataset", "data_subject", "data_use"]:
         server_resources = list_server_resources(
             url,
